<?php
namespace Teknisa\SM\Controller;

use Teknisa\SM\Controller\SMCrud;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use Teknisa\SM\Service\Sm00006001TabelaPrecoServicoService;
use Teknisa\Libs\Util\NewCode;

class Sm00006001TabelaPrecoServicoController extends SMCrud
{
    protected $dataSourceName = 'fct_itprecbaseserv_widget';
    protected $ServiceTabPrecoServico;
    protected $newCode;
   
    public function __construct ($crudService, $environment, Sm00006001TabelaPrecoServicoService $ServiceTabPrecoServico,  NewCode $newCode) {
        parent::__construct($crudService, $environment);
        $this->newCode = $newCode;
        $this->ServiceTabPrecoServico  = $ServiceTabPrecoServico;
    }
   
    /**
     * A função "validaServicoTabela" verifica se o serviço 
     * que está sendo relacionado já existe está relacionadoao serviço.
     */
    public function validaServicoTabela(Request\Row $request, Response $response) {
    
        $row = $request->getRow();
        
        $servOrca = $row['CDSERVORCA']; 
        $precBaseServ = $row['CDPRECBASESERV'];
        $tipoMedida = $row['CDTPMEDIDASERV'];
        
        $ValidaServTabela = $this->ServiceTabPrecoServico->validaServicoTabela($servOrca, $precBaseServ, $tipoMedida);
        
        $dtsValServTabela = new DataSet('VALIDASERV', array('VALIDA'=>$ValidaServTabela));
        
        $response->addDataSet($dtsValServTabela);
    
    } 
    
    public function save(Request $request, Response $response) {
        
        $rows = $request->getDataSet()->getRows();
        
        $ItPrecBServ = array();
      
        foreach($rows as $row) {
            if ($row["__is_new"]) {
                
                $row['NRSEQITPRECBSERV'] = $this->newCode->getCodeByTableName("FCT_ITPRECBASESERV", $this->environment->getNrOrg());
                
                $ItPrecBServ[] = $row['NRSEQITPRECBSERV'];
                
            }
        }
        
        $request->setParameter('dbname', 'fct_itprecbaseserv_widget');
        
        parent::save($request, $response);
        
        $response->addDataSet(new DataSet('columnsToReturn' , $this->crudService->getColumnsToReturn()));
        $response->addDataSet(new DataSet('ITPRECBASESERV', $ItPrecBServ));
    }
    
     /**
     * A função "sincronizarVariacaoPreco" executa a procedure
     * "FCT_SINCRONIZAR_VARIACAO_PRECO".
     */
     
    public function sincronizarVariacaoPreco (Request\Row $request){
 
         $row = $request->getRow();
            
         $itPrecBaseServ = $row['NRSEQITPRECBSERV']; 
         $tipo = $row['TIPO'];   
            
         $nrorg = $this->environment->getNrOrg();
         $operador = $this->environment->getCdOperador();
         
         $this->ServiceTabPrecoServico->executarProcedureFctSincronizarVariacaoPreco($itPrecBaseServ, $tipo, $nrorg, $operador);
            
    }
    
    public function find(Request\Filter $request, Response $response) {
    
        $request->setParameter('dbname', 'fct_itprecbaseserv_widget');
        parent::find($request, $response);
    
    }
    
    public function delete(Request $request, Response $response) {
    
        $request->setParameter('dbname', 'fct_itprecbaseserv_widget');
        parent::delete($request, $response);
    
    }

    public function salvarCopiaOutraMoeda(Request\Row $request, Response $response) {
        try {
            $row        = $request->getRow();
            $nrorg      = $this->environment->getNrOrg();
            $cdoperador = $this->environment->getCdOperador();
            
            $cdprecbaseserv        = $row["CDPRECBASESERV"];
            $fatorconversao        = $row["fator_conversao"];
            $nrmoeda               = $row["NRMOEDA"];
            $nmmoeda               = $row["NMMOEDA"];
            
            $this->ServiceTabPrecoServico->salvarCopiaOutraMoeda($cdprecbaseserv, $fatorconversao, $nrmoeda, $nmmoeda, $nrorg, $cdoperador);
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
}
?>